@@ -27,7 +27,8 @@
 #define ROCWMMA_MAPPING_UTIL_HPP
 
 #include "types.hpp"
-
+#include "utility/type_traits.hpp"
+#include "vector.hpp"
 namespace rocwmma
 {
     // Fwd declaration
@@ -58,12 +59,12 @@ namespace rocwmma
             ROCWMMA_DEVICE constexpr static inline WorkgroupCoordT workgroupCoord();
 
             // Size of workgroup, normalized to wave count.
-            template <bool IsConst                        = (TBlockX > 0u && TBlockY > 0u),
-                      typename std::enable_if_t<IsConst>* = nullptr>
+            template <bool IsConst          = (TBlockX > 0u && TBlockY > 0u),
+                      enable_if_t<IsConst>* = nullptr>
             ROCWMMA_DEVICE constexpr static inline WorkgroupDimT workgroupDim();
 
-            template <bool IsConst                         = (TBlockX > 0u && TBlockY > 0u),
-                      typename std::enable_if_t<!IsConst>* = nullptr>
+            template <bool IsConst           = (TBlockX > 0u && TBlockY > 0u),
+                      enable_if_t<!IsConst>* = nullptr>
             ROCWMMA_DEVICE static inline WorkgroupDimT workgroupDim();
         };
 
@@ -93,8 +94,8 @@ namespace rocwmma
 
             enum : uint32_t
             {
-                MajorIndex = std::is_same<DataOrientation, row_major>::value ? 0 : 1,
-                MinorIndex = std::is_same<DataOrientation, row_major>::value ? 1 : 0
+                MajorIndex = is_same<DataOrientation, row_major>::value ? 0 : 1,
+                MinorIndex = is_same<DataOrientation, row_major>::value ? 1 : 0
             };
 
             // Determine the leading dimension of a matrix.
