@@ -27,7 +27,7 @@
 #ifndef ROCWMMA_VECTOR_IMPL_HPP
 #define ROCWMMA_VECTOR_IMPL_HPP
 
-#include "vector.hpp"
+#include "utility/sequence.hpp"
 
 namespace rocwmma
 {
@@ -69,8 +69,7 @@ namespace rocwmma
             };
             struct Mod
             {
-                template <typename TT,
-                          typename std::enable_if<std::is_integral<TT>{}>::type* = nullptr>
+                template <typename TT, typename enable_if<is_integral<TT>{}>::type* = nullptr>
                 ROCWMMA_HOST_DEVICE constexpr static inline auto exec(TT lhs, TT rhs)
                 {
                     return lhs % rhs;
@@ -78,8 +77,7 @@ namespace rocwmma
             };
             struct Minus
             {
-                template <typename TT,
-                          typename std::enable_if<std::is_signed<TT>{}>::type* = nullptr>
+                template <typename TT, typename enable_if<is_signed<TT>{}>::type* = nullptr>
                 ROCWMMA_HOST_DEVICE constexpr static inline auto exec(TT lhs)
                 {
                     return -lhs;
@@ -92,8 +90,7 @@ namespace rocwmma
         {
             struct And
             {
-                template <typename TT,
-                          typename std::enable_if<std::is_integral<TT>{}>::type* = nullptr>
+                template <typename TT, typename enable_if<is_integral<TT>{}>::type* = nullptr>
                 ROCWMMA_HOST_DEVICE constexpr static inline TT exec(TT lhs, TT rhs)
                 {
                     return lhs & rhs;
@@ -102,8 +99,7 @@ namespace rocwmma
 
             struct Or
             {
-                template <typename TT,
-                          typename std::enable_if<std::is_integral<TT>{}>::type* = nullptr>
+                template <typename TT, typename enable_if<is_integral<TT>{}>::type* = nullptr>
                 ROCWMMA_HOST_DEVICE constexpr static inline TT exec(TT lhs, TT rhs)
                 {
                     return lhs | rhs;
@@ -112,8 +108,7 @@ namespace rocwmma
 
             struct Not
             {
-                template <typename TT,
-                          typename std::enable_if<std::is_integral<TT>{}>::type* = nullptr>
+                template <typename TT, typename enable_if<is_integral<TT>{}>::type* = nullptr>
                 ROCWMMA_HOST_DEVICE constexpr static inline TT exec(TT lhs)
                 {
                     return ~lhs;
@@ -122,8 +117,7 @@ namespace rocwmma
 
             struct Xor
             {
-                template <typename TT,
-                          typename std::enable_if<std::is_integral<TT>{}>::type* = nullptr>
+                template <typename TT, typename enable_if<is_integral<TT>{}>::type* = nullptr>
                 ROCWMMA_HOST_DEVICE constexpr static inline TT exec(TT lhs, TT rhs)
                 {
                     return lhs ^ rhs;
@@ -132,8 +126,7 @@ namespace rocwmma
 
             struct ShiftR
             {
-                template <typename TT,
-                          typename std::enable_if<std::is_integral<TT>{}>::type* = nullptr>
+                template <typename TT, typename enable_if<is_integral<TT>{}>::type* = nullptr>
                 ROCWMMA_HOST_DEVICE constexpr static inline TT exec(TT lhs, TT rhs)
                 {
                     return lhs >> rhs;
@@ -142,8 +135,7 @@ namespace rocwmma
 
             struct ShiftL
             {
-                template <typename TT,
-                          typename std::enable_if<std::is_integral<TT>{}>::type* = nullptr>
+                template <typename TT, typename enable_if<is_integral<TT>{}>::type* = nullptr>
                 ROCWMMA_HOST_DEVICE constexpr static inline TT exec(TT lhs, TT rhs)
                 {
                     return lhs >> rhs;
@@ -157,7 +149,7 @@ namespace rocwmma
             struct And
             {
                 template <typename TT,
-                          typename std::enable_if<std::is_convertible<TT, bool>{}>::type* = nullptr>
+                          typename enable_if<is_convertible<TT, bool>{}>::type* = nullptr>
                 ROCWMMA_HOST_DEVICE constexpr static inline auto exec(TT lhs, TT rhs)
                 {
                     return lhs && rhs;
@@ -167,7 +159,7 @@ namespace rocwmma
             struct Or
             {
                 template <typename TT,
-                          typename std::enable_if<std::is_convertible<TT, bool>{}>::type* = nullptr>
+                          typename enable_if<is_convertible<TT, bool>{}>::type* = nullptr>
                 ROCWMMA_HOST_DEVICE constexpr static inline auto exec(TT lhs, TT rhs)
                 {
                     return lhs || rhs;
@@ -177,7 +169,7 @@ namespace rocwmma
             struct Not
             {
                 template <typename TT,
-                          typename std::enable_if<std::is_convertible<TT, bool>{}>::type* = nullptr>
+                          typename enable_if<is_convertible<TT, bool>{}>::type* = nullptr>
                 ROCWMMA_HOST_DEVICE constexpr static inline auto exec(TT lhs)
                 {
                     return !lhs;
@@ -244,82 +236,6 @@ namespace rocwmma
 
         } // namespace RelationalOp
 
-        template <class IntT, IntT val>
-        struct integral_constant
-        {
-            static constexpr IntT value = val;
-            using value_type            = IntT;
-            using type                  = integral_constant;
-            constexpr operator value_type() const noexcept
-            {
-                return value;
-            }
-            constexpr value_type operator()() const noexcept
-            {
-                return value;
-            }
-        };
-
-        template <typename Int, Int... Ints>
-        struct integer_sequence
-        {
-            using value_type = Int;
-            constexpr integer_sequence() {}
-            static constexpr std::size_t size() noexcept
-            {
-                return sizeof...(Ints);
-            }
-        };
-
-        template <std::size_t... Indices>
-        using index_sequence = integer_sequence<std::size_t, Indices...>;
-
-        namespace
-        {
-            // Merge two integer sequences, adding an offset to the right-hand side.
-            template <typename Offset, typename Lhs, typename Rhs>
-            struct merge;
-
-            template <typename Int, Int Offset, Int... Lhs, Int... Rhs>
-            struct merge<integral_constant<Int, Offset>,
-                         integer_sequence<Int, Lhs...>,
-                         integer_sequence<Int, Rhs...>>
-            {
-                using type = integer_sequence<Int, Lhs..., (Offset + Rhs)...>;
-            };
-
-            template <typename Int, typename N>
-            struct log_make_sequence
-            {
-                using L    = integral_constant<Int, N::value / 2>;
-                using R    = integral_constant<Int, N::value - L::value>;
-                using type = typename merge<L,
-                                            typename log_make_sequence<Int, L>::type,
-                                            typename log_make_sequence<Int, R>::type>::type;
-            };
-
-            // An empty sequence.
-            template <typename Int>
-            struct log_make_sequence<Int, integral_constant<Int, 0>>
-            {
-                using type = integer_sequence<Int>;
-            };
-
-            // A single-element sequence.
-            template <typename Int>
-            struct log_make_sequence<Int, integral_constant<Int, 1>>
-            {
-                using type = integer_sequence<Int, 0>;
-            };
-        }
-
-        template <typename Int, Int N>
-        using make_integer_sequence =
-            typename log_make_sequence<Int, integral_constant<Int, N>>::type;
-
-        template <std::size_t N>
-        using make_index_sequence = make_integer_sequence<std::size_t, N>;
-
         // Helpers for expression expansion, specific to non_native_vector_base
         template <uint32_t... ns>
         using SeqT = integer_sequence<uint32_t, ns...>;
@@ -360,14 +276,14 @@ namespace rocwmma
         }
 
     } // namespace detail
-
+    
     // NOTE: The single-valued 'broadcast' constructor can only be used with Rank > 1.
     // Why? The bCast function constructs the vector with <Rank> copies of the input val.
     // When Rank == 1, this would create an endless ctor->bcast->ctor->bcast... loop.
     // As a solution, Rank == 1 should fall into the ctor(Ts... args) for initializer
     // list construction, and NOT bCast initialization.
     template <typename T, unsigned int Rank>
-    template <typename U, typename std::enable_if<(std::is_same<U, T>{}) && (Rank > 1)>::type*>
+    template <typename U, typename enable_if<(is_same<U, T>{}) && (Rank > 1)>::type*>
     ROCWMMA_HOST_DEVICE constexpr non_native_vector_base<T, Rank>::non_native_vector_base(
         T x_) noexcept
         : non_native_vector_base(detail::template bCast<VecT>(x_, detail::Seq<Rank>{}))
@@ -378,7 +294,7 @@ namespace rocwmma
     // Default template depth is currently not deep enough to
     // support vector sizes of 512
     template <typename T, unsigned int Rank>
-    template <typename... Ts, typename U, typename std::enable_if<(sizeof...(Ts) == Rank)>::type*>
+    template <typename... Ts, typename U, typename enable_if<(sizeof...(Ts) == Rank)>::type*>
     ROCWMMA_HOST_DEVICE constexpr non_native_vector_base<T, Rank>::non_native_vector_base(
         Ts... args) noexcept
         : d{static_cast<T>(args)...}
@@ -398,7 +314,6 @@ namespace rocwmma
     {
         return d[idx];
     }
-
     template <typename T, unsigned int Rank>
     ROCWMMA_HOST_DEVICE constexpr inline auto
         non_native_vector_base<T, Rank>::operator+=(const VecT& x_) noexcept -> VecT&
@@ -460,7 +375,7 @@ namespace rocwmma
     }
 
     template <typename T, unsigned int Rank>
-    template <typename U, typename std::enable_if<std::is_integral<U>{}>::type*>
+    template <typename U, enable_if_integral_t<U>*>
     ROCWMMA_HOST_DEVICE inline auto
         non_native_vector_base<T, Rank>::operator%=(const VecT& x_) noexcept -> VecT&
     {
@@ -468,7 +383,7 @@ namespace rocwmma
     }
 
     template <typename T, unsigned int Rank>
-    template <typename U, typename std::enable_if<std::is_signed<U>{}>::type*>
+    template <typename U, enable_if_signed_t<U>*>
     ROCWMMA_HOST_DEVICE inline auto non_native_vector_base<T, Rank>::operator-() const noexcept
         -> VecT
     {
@@ -477,7 +392,7 @@ namespace rocwmma
 
     // @cond
     template <typename T, unsigned int Rank>
-    template <typename U, typename std::enable_if<std::is_integral<U>{}>::type*>
+    template <typename U, enable_if_integral_t<U>*>
     ROCWMMA_HOST_DEVICE inline auto
         non_native_vector_base<T, Rank>::operator&=(const VecT& x_) noexcept -> VecT&
     {
@@ -486,7 +401,7 @@ namespace rocwmma
     // @endcond
 
     template <typename T, unsigned int Rank>
-    template <typename U, typename std::enable_if<std::is_integral<U>{}>::type*>
+    template <typename U, enable_if_integral_t<U>*>
     ROCWMMA_HOST_DEVICE inline auto
         non_native_vector_base<T, Rank>::operator|=(const VecT& x_) noexcept -> VecT&
     {
@@ -494,7 +409,7 @@ namespace rocwmma
     }
 
     template <typename T, unsigned int Rank>
-    template <typename U, typename std::enable_if<std::is_integral<U>{}>::type*>
+    template <typename U, enable_if_integral_t<U>*>
     ROCWMMA_HOST_DEVICE inline auto non_native_vector_base<T, Rank>::operator~() const noexcept
         -> VecT
     {
@@ -502,7 +417,7 @@ namespace rocwmma
     }
 
     template <typename T, unsigned int Rank>
-    template <typename U, typename std::enable_if<std::is_integral<U>{}>::type*>
+    template <typename U, enable_if_integral_t<U>*>
     ROCWMMA_HOST_DEVICE inline auto
         non_native_vector_base<T, Rank>::operator^=(const VecT& x_) noexcept -> VecT&
     {
@@ -510,7 +425,7 @@ namespace rocwmma
     }
 
     template <typename T, unsigned int Rank>
-    template <typename U, typename std::enable_if<std::is_integral<U>{}>::type*>
+    template <typename U, enable_if_integral_t<U>*>
     ROCWMMA_HOST_DEVICE inline auto
         non_native_vector_base<T, Rank>::operator>>=(const VecT& x_) noexcept -> VecT&
     {
@@ -518,7 +433,7 @@ namespace rocwmma
     }
 
     template <typename T, unsigned int Rank>
-    template <typename U, typename std::enable_if<std::is_integral<U>{}>::type*>
+    template <typename U, enable_if_integral_t<U>*>
     ROCWMMA_HOST_DEVICE inline auto
         non_native_vector_base<T, Rank>::operator<<=(const VecT& x_) noexcept -> VecT&
     {
@@ -660,44 +575,43 @@ namespace rocwmma
 /// OR native vector extension. The latter doesn't have the required built-in broadcast.     ///
 ////////////////////////////////////////////////////////////////////////////////////////////////
 
-#define ROCWMMA_REGISTER_HIP_VECTOR_BASE(TYPE, RANK, STORAGE_IMPL)                             \
-    template <>                                                                                \
-    struct HIP_vector_base<TYPE, RANK>                                                         \
-    {                                                                                          \
-        STORAGE_IMPL(TYPE, RANK);                                                              \
-                                                                                               \
-        using value_type = TYPE;                                                               \
-                                                                                               \
-        ROCWMMA_HOST_DEVICE                                                                    \
-        HIP_vector_base() = default;                                                           \
-        template <typename... ArgsT,                                                           \
-                  typename U                                                 = TYPE,           \
-                  typename std::enable_if<(sizeof...(ArgsT) == RANK)>::type* = nullptr>        \
-        ROCWMMA_HOST_DEVICE constexpr HIP_vector_base(ArgsT... args) noexcept                  \
-            : data{args...}                                                                    \
-        {                                                                                      \
-        }                                                                                      \
-                                                                                               \
-        template <                                                                             \
-            typename U                                                              = TYPE,    \
-            typename std::enable_if<(std::is_same<U, TYPE>{}) && (RANK > 1)>::type* = nullptr> \
-        ROCWMMA_HOST_DEVICE constexpr explicit HIP_vector_base(TYPE val) noexcept              \
-            : HIP_vector_base(rocwmma::detail::template bCast<HIP_vector_base>(                \
-                val, rocwmma::detail::Seq<RANK>{}))                                            \
-        {                                                                                      \
-        }                                                                                      \
-                                                                                               \
-        ROCWMMA_HOST_DEVICE                                                                    \
-        constexpr HIP_vector_base(const HIP_vector_base&) = default;                           \
-                                                                                               \
-        ROCWMMA_HOST_DEVICE                                                                    \
-        constexpr HIP_vector_base(HIP_vector_base&&) = default;                                \
-                                                                                               \
-        ROCWMMA_HOST_DEVICE                                                                    \
-        ~HIP_vector_base() = default;                                                          \
-                                                                                               \
-        ROCWMMA_HOST_DEVICE                                                                    \
-        HIP_vector_base& operator=(const HIP_vector_base& x_) noexcept = default;              \
+#define ROCWMMA_REGISTER_HIP_VECTOR_BASE(TYPE, RANK, STORAGE_IMPL)                              \
+    template <>                                                                                 \
+    struct HIP_vector_base<TYPE, RANK>                                                          \
+    {                                                                                           \
+        STORAGE_IMPL(TYPE, RANK);                                                               \
+                                                                                                \
+        using value_type = TYPE;                                                                \
+                                                                                                \
+        ROCWMMA_HOST_DEVICE                                                                     \
+        HIP_vector_base() = default;                                                            \
+        template <typename... ArgsT,                                                            \
+                  typename U                                        = TYPE,                     \
+                  rocwmma::enable_if_t<(sizeof...(ArgsT) == RANK)>* = nullptr>                  \
+        ROCWMMA_HOST_DEVICE constexpr HIP_vector_base(ArgsT... args) noexcept                   \
+            : data{args...}                                                                     \
+        {                                                                                       \
+        }                                                                                       \
+                                                                                                \
+        template <typename U                                                         = TYPE,    \
+                  rocwmma::enable_if_t<(rocwmma::is_same<U, TYPE>{}) && (RANK > 1)>* = nullptr> \
+        ROCWMMA_HOST_DEVICE constexpr explicit HIP_vector_base(TYPE val) noexcept               \
+            : HIP_vector_base(rocwmma::detail::template bCast<HIP_vector_base>(                 \
+                val, rocwmma::detail::Seq<RANK>{}))                                             \
+        {                                                                                       \
+        }                                                                                       \
+                                                                                                \
+        ROCWMMA_HOST_DEVICE                                                                     \
+        constexpr HIP_vector_base(const HIP_vector_base&) = default;                            \
+                                                                                                \
+        ROCWMMA_HOST_DEVICE                                                                     \
+        constexpr HIP_vector_base(HIP_vector_base&&) = default;                                 \
+                                                                                                \
+        ROCWMMA_HOST_DEVICE                                                                     \
+        ~HIP_vector_base() = default;                                                           \
+                                                                                                \
+        ROCWMMA_HOST_DEVICE                                                                     \
+        HIP_vector_base& operator=(const HIP_vector_base& x_) noexcept = default;               \
     };
 
 ///////////////////////////////////////////////////////////////////////////////////////////////////
