@@ -51,7 +51,7 @@
 
 // Library includes
 
-#ifdef ROCWMMA_VALIDATION_TESTS
+#if ROCWMMA_VALIDATION_TESTS
 #include "reference.hpp" // Vanilla CPU kernel
 #endif // ROCWMMA_VALIDATION_TESTS
 
@@ -110,6 +110,8 @@ namespace rocwmma
         auto isGfx11  = (deviceArch == DeviceInfo::GFX1100) || (deviceArch == DeviceInfo::GFX1101)
                        || (deviceArch == DeviceInfo::GFX1102);
 
+        auto isGfx12 = (deviceArch == DeviceInfo::GFX1200) || (deviceArch == DeviceInfo::GFX1201);
+
         // Datatypes
         auto isF64 = std::is_same<DataT, float64_t>::value;
 
@@ -134,7 +136,10 @@ namespace rocwmma
         // gfx11 only supports f16, i8 and bf16 inputs with block size 16
         bool gfx11Check = !(isGfx11 && ((!isF16 && !isBF16 && !isI8) || !is16x16));
 
-        return unsupportedDeviceCheck && gfx908F64Check && gfx11Check;
+        // gfx12 only supports f16, i8 and bf16 inputs with block size 16
+        bool gfx12Check = !(isGfx12 && ((!isF16 && !isBF16 && !isI8) || !is16x16));
+
+        return unsupportedDeviceCheck && gfx908F64Check && gfx11Check && gfx12Check;
     }
 
     template <uint32_t TileSize, typename DataT>
@@ -156,11 +161,11 @@ namespace rocwmma
         mM = mK = mB = 0;
         mMPadded = mKPadded = 0;
         mRepeats =
-#ifdef ROCWMMA_VALIDATION_TESTS
+#if ROCWMMA_VALIDATION_TESTS
             1;
 #else
             5;
-#endif
+#endif // ROCWMMA_VALIDATION_TESTS
 
         mRunFlag = true;
 
@@ -187,10 +192,10 @@ namespace rocwmma
                       << "DataT, "
                       << "Direction, "
                       << "MatM, MatK, MatB, "
-#if defined(ROCWMMA_VALIDATION_TESTS)
+#if ROCWMMA_VALIDATION_TESTS
                       << "maxRelativeDiff, "
                       << "tolerance, "
-#endif
+#endif // ROCWMMA_VALIDATION_TESTS
                       << "elapsedMs, "
                       << "Problem Size(GFlops), "
                       << "TFlops/s, "
@@ -206,9 +211,9 @@ namespace rocwmma
                           << (passDirection == DlrmDirection_t::Forward ? "Forwards" : "Backwards")
                           << ", " << mM << ", " << mK << ", " << mB << ", "
 
-#if defined(ROCWMMA_VALIDATION_TESTS)
+#if ROCWMMA_VALIDATION_TESTS
                           << "n/a, "
-#endif
+#endif // ROCWMMA_VALIDATION_TESTS
                           << "n/a, n/a, n/a, n/a, SKIPPED" << std::endl;
         }
         else
@@ -217,12 +222,12 @@ namespace rocwmma
                           << (passDirection == DlrmDirection_t::Forward ? "Forwards" : "Backwards")
                           << ", " << mM << ", " << mK << ", " << mB << ", "
 
-#if defined(ROCWMMA_VALIDATION_TESTS)
+#if ROCWMMA_VALIDATION_TESTS
                           << mMaxRelativeError << ", "
-#endif
+#endif // ROCWMMA_VALIDATION_TESTS
                           << mElapsedTimeMs << ", " << mTotalGFlops << ", " << mMeasuredTFlopsPerSec
                           << ", " << mEfficiency << ", "
-#if defined(ROCWMMA_VALIDATION_TESTS)
+#if ROCWMMA_VALIDATION_TESTS
                           << (mValidationResult ? "PASSED" : "FAILED")
 #else
                           << "BENCH"
@@ -275,7 +280,7 @@ namespace rocwmma
             {
                 MatrixUtil<row_major>::fillLaunchKernel(
                     dataInstance->deviceInput().get(), mM, mK, mB);
-#if defined(ROCWMMA_VALIDATION_TESTS)
+#if ROCWMMA_VALIDATION_TESTS
                 dataInstance->copyDeviceToHostFwdInput();
 #endif // ROCWMMA_VALIDATION_TESTS
             }
@@ -286,7 +291,7 @@ namespace rocwmma
                     dataInstance->deviceInput().get(), mM, mK, mB);
                 MatrixUtil<row_major>::fillLaunchKernel(
                     dataInstance->deviceUpstreamGrad().get(), 1, gradSize, mB);
-#if defined(ROCWMMA_VALIDATION_TESTS)
+#if ROCWMMA_VALIDATION_TESTS
                 dataInstance->copyDeviceToHostBwdInput();
 #endif // ROCWMMA_VALIDATION_TESTS
             }
@@ -418,7 +423,7 @@ namespace rocwmma
             CHECK_HIP_ERROR(hipEventDestroy(startEvent));
             CHECK_HIP_ERROR(hipEventDestroy(stopEvent));
 
-#if defined(ROCWMMA_VALIDATION_TESTS)
+#if ROCWMMA_VALIDATION_TESTS
 
             // Run reference CPU kernel
             std::function<void()> cpuKernel;
@@ -447,14 +452,14 @@ namespace rocwmma
                 };
             }
             cpuKernel();
-#endif
+#endif // ROCWMMA_VALIDATION_TESTS
         }
     }
 
     template <uint32_t TileSize, typename DataT>
     void DlrmKernelBase<TileSize, DataT>::validateResults()
     {
-#ifdef ROCWMMA_VALIDATION_TESTS
+#if ROCWMMA_VALIDATION_TESTS
         if(mRunFlag)
         {
             auto& dataInstance = DataStorage::instance();
