@@ -100,7 +100,7 @@ namespace rocwmma
         enum struct Gfx11Predicates : bool
         {
             // Valid for gfx11 only
-            ArchTest = (bool)TestTraits::Arch::IsGfx11,
+            ArchTest = (bool)TestTraits::Arch::IsGfx11 || (bool)TestTraits::Arch::IsGfx12,
 
             // AB inputs are duplicated, single buffered
             // C tiles are unpacked.
