@@ -2,7 +2,7 @@
  *
  * MIT License
  *
- * Copyright (C) 2021-2024 Advanced Micro Devices, Inc. All rights reserved.
+ * Copyright (C) 2021-2025 Advanced Micro Devices, Inc. All rights reserved.
  *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to deal
@@ -25,6 +25,16 @@
  *******************************************************************************/
 
 #define ROCWMMA_INSTANTIATE_GEMM_KERNEL_BASE(InputT, OutputT, ComputeT) \
+    template struct GemmKernelBase<16u,                                 \
+                                   16u,                                 \
+                                   4u,                                  \
+                                   InputT,                              \
+                                   OutputT,                             \
+                                   ComputeT,                            \
+                                   row_major,                           \
+                                   row_major,                           \
+                                   row_major,                           \
+                                   row_major>;                          \
     template struct GemmKernelBase<16u,                                 \
                                    16u,                                 \
                                    16u,                                 \
@@ -75,6 +85,16 @@
                                    row_major,                           \
                                    row_major,                           \
                                    row_major>;                          \
+    template struct GemmKernelBase<32u,                                 \
+                                   32u,                                 \
+                                   2u,                                  \
+                                   InputT,                              \
+                                   OutputT,                             \
+                                   ComputeT,                            \
+                                   row_major,                           \
+                                   row_major,                           \
+                                   row_major,                           \
+                                   row_major>;                          \
     template struct GemmKernelBase<32u,                                 \
                                    32u,                                 \
                                    8u,                                  \
@@ -125,6 +145,16 @@
                                    row_major,                           \
                                    row_major,                           \
                                    row_major>;                          \
+    template struct GemmKernelBase<16u,                                 \
+                                   16u,                                 \
+                                   4u,                                  \
+                                   InputT,                              \
+                                   OutputT,                             \
+                                   ComputeT,                            \
+                                   row_major,                           \
+                                   col_major,                           \
+                                   row_major,                           \
+                                   row_major>;                          \
     template struct GemmKernelBase<16u,                                 \
                                    16u,                                 \
                                    16u,                                 \
@@ -175,6 +205,16 @@
                                    col_major,                           \
                                    row_major,                           \
                                    row_major>;                          \
+    template struct GemmKernelBase<32u,                                 \
+                                   32u,                                 \
+                                   2u,                                  \
+                                   InputT,                              \
+                                   OutputT,                             \
+                                   ComputeT,                            \
+                                   row_major,                           \
+                                   col_major,                           \
+                                   row_major,                           \
+                                   row_major>;                          \
     template struct GemmKernelBase<32u,                                 \
                                    32u,                                 \
                                    8u,                                  \
@@ -225,6 +265,16 @@
                                    col_major,                           \
                                    row_major,                           \
                                    row_major>;                          \
+    template struct GemmKernelBase<16u,                                 \
+                                   16u,                                 \
+                                   4u,                                  \
+                                   InputT,                              \
+                                   OutputT,                             \
+                                   ComputeT,                            \
+                                   row_major,                           \
+                                   row_major,                           \
+                                   col_major,                           \
+                                   col_major>;                          \
     template struct GemmKernelBase<16u,                                 \
                                    16u,                                 \
                                    16u,                                 \
@@ -275,6 +325,16 @@
                                    row_major,                           \
                                    col_major,                           \
                                    col_major>;                          \
+    template struct GemmKernelBase<32u,                                 \
+                                   32u,                                 \
+                                   2u,                                  \
+                                   InputT,                              \
+                                   OutputT,                             \
+                                   ComputeT,                            \
+                                   row_major,                           \
+                                   row_major,                           \
+                                   col_major,                           \
+                                   col_major>;                          \
     template struct GemmKernelBase<32u,                                 \
                                    32u,                                 \
                                    8u,                                  \
@@ -325,6 +385,16 @@
                                    row_major,                           \
                                    col_major,                           \
                                    col_major>;                          \
+    template struct GemmKernelBase<16u,                                 \
+                                   16u,                                 \
+                                   4u,                                  \
+                                   InputT,                              \
+                                   OutputT,                             \
+                                   ComputeT,                            \
+                                   row_major,                           \
+                                   col_major,                           \
+                                   col_major,                           \
+                                   col_major>;                          \
     template struct GemmKernelBase<16u,                                 \
                                    16u,                                 \
                                    16u,                                 \
@@ -375,6 +445,16 @@
                                    col_major,                           \
                                    col_major,                           \
                                    col_major>;                          \
+    template struct GemmKernelBase<32u,                                 \
+                                   32u,                                 \
+                                   2u,                                  \
+                                   InputT,                              \
+                                   OutputT,                             \
+                                   ComputeT,                            \
+                                   row_major,                           \
+                                   col_major,                           \
+                                   col_major,                           \
+                                   col_major>;                          \
     template struct GemmKernelBase<32u,                                 \
                                    32u,                                 \
                                    8u,                                  \
@@ -425,6 +505,16 @@
                                    col_major,                           \
                                    col_major,                           \
                                    col_major>;                          \
+    template struct GemmKernelBase<16u,                                 \
+                                   16u,                                 \
+                                   4u,                                  \
+                                   InputT,                              \
+                                   OutputT,                             \
+                                   ComputeT,                            \
+                                   col_major,                           \
+                                   row_major,                           \
+                                   row_major,                           \
+                                   row_major>;                          \
     template struct GemmKernelBase<16u,                                 \
                                    16u,                                 \
                                    16u,                                 \
@@ -475,6 +565,16 @@
                                    row_major,                           \
                                    row_major,                           \
                                    row_major>;                          \
+    template struct GemmKernelBase<32u,                                 \
+                                   32u,                                 \
+                                   2u,                                  \
+                                   InputT,                              \
+                                   OutputT,                             \
+                                   ComputeT,                            \
+                                   col_major,                           \
+                                   row_major,                           \
+                                   row_major,                           \
+                                   row_major>;                          \
     template struct GemmKernelBase<32u,                                 \
                                    32u,                                 \
                                    8u,                                  \
@@ -525,6 +625,16 @@
                                    row_major,                           \
                                    row_major,                           \
                                    row_major>;                          \
+    template struct GemmKernelBase<16u,                                 \
+                                   16u,                                 \
+                                   4,                                   \
+                                   InputT,                              \
+                                   OutputT,                             \
+                                   ComputeT,                            \
+                                   col_major,                           \
+                                   col_major,                           \
+                                   row_major,                           \
+                                   row_major>;                          \
     template struct GemmKernelBase<16u,                                 \
                                    16u,                                 \
                                    16u,                                 \
@@ -575,6 +685,16 @@
                                    col_major,                           \
                                    row_major,                           \
                                    row_major>;                          \
+    template struct GemmKernelBase<32u,                                 \
+                                   32u,                                 \
+                                   2u,                                  \
+                                   InputT,                              \
+                                   OutputT,                             \
+                                   ComputeT,                            \
+                                   col_major,                           \
+                                   col_major,                           \
+                                   row_major,                           \
+                                   row_major>;                          \
     template struct GemmKernelBase<32u,                                 \
                                    32u,                                 \
                                    8u,                                  \
@@ -625,6 +745,16 @@
                                    col_major,                           \
                                    row_major,                           \
                                    row_major>;                          \
+    template struct GemmKernelBase<16u,                                 \
+                                   16u,                                 \
+                                   4u,                                  \
+                                   InputT,                              \
+                                   OutputT,                             \
+                                   ComputeT,                            \
+                                   col_major,                           \
+                                   row_major,                           \
+                                   col_major,                           \
+                                   col_major>;                          \
     template struct GemmKernelBase<16u,                                 \
                                    16u,                                 \
                                    16u,                                 \
@@ -675,6 +805,16 @@
                                    row_major,                           \
                                    col_major,                           \
                                    col_major>;                          \
+    template struct GemmKernelBase<32u,                                 \
+                                   32u,                                 \
+                                   2u,                                  \
+                                   InputT,                              \
+                                   OutputT,                             \
+                                   ComputeT,                            \
+                                   col_major,                           \
+                                   row_major,                           \
+                                   col_major,                           \
+                                   col_major>;                          \
     template struct GemmKernelBase<32u,                                 \
                                    32u,                                 \
                                    8u,                                  \
@@ -725,6 +865,16 @@
                                    row_major,                           \
                                    col_major,                           \
                                    col_major>;                          \
+    template struct GemmKernelBase<16u,                                 \
+                                   16u,                                 \
+                                   4u,                                  \
+                                   InputT,                              \
+                                   OutputT,                             \
+                                   ComputeT,                            \
+                                   col_major,                           \
+                                   col_major,                           \
+                                   col_major,                           \
+                                   col_major>;                          \
     template struct GemmKernelBase<16u,                                 \
                                    16u,                                 \
                                    16u,                                 \
@@ -775,6 +925,16 @@
                                    col_major,                           \
                                    col_major,                           \
                                    col_major>;                          \
+    template struct GemmKernelBase<32u,                                 \
+                                   32u,                                 \
+                                   2u,                                  \
+                                   InputT,                              \
+                                   OutputT,                             \
+                                   ComputeT,                            \
+                                   col_major,                           \
+                                   col_major,                           \
+                                   col_major,                           \
+                                   col_major>;                          \
     template struct GemmKernelBase<32u,                                 \
                                    32u,                                 \
                                    8u,                                  \
