@@ -95,24 +95,34 @@ namespace rocwmma
             IsWave32 = (WaveSize == Constants::AMDGCN_WAVE_SIZE_32),
             IsWave64 = (WaveSize == Constants::AMDGCN_WAVE_SIZE_64),
 
-            IsGfx908  = (ArchId == Constants::AMDGCN_ARCH_ID_GFX908),
-            IsGfx90A  = (ArchId == Constants::AMDGCN_ARCH_ID_GFX90A),
-            IsGfx940  = (ArchId == Constants::AMDGCN_ARCH_ID_GFX940),
-            IsGfx941  = (ArchId == Constants::AMDGCN_ARCH_ID_GFX941),
-            IsGfx942  = (ArchId == Constants::AMDGCN_ARCH_ID_GFX942),
+            IsGfx908 = (ArchId == Constants::AMDGCN_ARCH_ID_GFX908),
+            IsGfx90A = (ArchId == Constants::AMDGCN_ARCH_ID_GFX90A),
+            IsGfx940 = (ArchId == Constants::AMDGCN_ARCH_ID_GFX940),
+            IsGfx941 = (ArchId == Constants::AMDGCN_ARCH_ID_GFX941),
+            IsGfx942 = (ArchId == Constants::AMDGCN_ARCH_ID_GFX942),
+
             IsGfx1100 = (ArchId == Constants::AMDGCN_ARCH_ID_GFX1100),
             IsGfx1101 = (ArchId == Constants::AMDGCN_ARCH_ID_GFX1101),
             IsGfx1102 = (ArchId == Constants::AMDGCN_ARCH_ID_GFX1102),
 
+            IsGfx1200 = (ArchId == Constants::AMDGCN_ARCH_ID_GFX1200),
+            IsGfx1201 = (ArchId == Constants::AMDGCN_ARCH_ID_GFX1201),
+
             IsGfx9  = IsGfx908 || IsGfx90A || IsGfx940 || IsGfx941 || IsGfx942,
             IsGfx11 = IsGfx1100 || IsGfx1101 || IsGfx1102,
+            IsGfx12 = IsGfx1200 || IsGfx1201,
         };
 
         enum struct InputType : bool
         {
             IsInt8    = std::is_same_v<InputT, int8_t>,
+
+            // Make sure to include fnuz f8 types
             IsFloat8  = std::is_same_v<InputT, float8_t>,
-            IsBFloat8 = std::is_same_v<InputT, bfloat8_t>,
+            IsFloat8Fnuz = std::is_same_v<InputT, float8_fnuz_t>,
+            IsBFloat8  = std::is_same_v<InputT, bfloat8_t>,
+            IsBFloat8Fnuz = std::is_same_v<InputT, bfloat8_fnuz_t>,
+
 #if !ROCWMMA_TESTS_NO_HALF
             IsHFloat16 = std::is_same_v<InputT, hfloat16_t>,
 #else
@@ -130,8 +140,10 @@ namespace rocwmma
         enum struct OutputType : bool
         {
             IsInt8    = std::is_same_v<OutputT, int8_t>,
-            IsFloat8  = std::is_same_v<OutputT, float8_t>,
-            IsBFloat8 = std::is_same_v<OutputT, bfloat8_t>,
+            IsFloat8  = std::is_same_v<InputT, float8_t>,
+            IsFloat8Fnuz = std::is_same_v<InputT, float8_fnuz_t>,
+            IsBFloat8  = std::is_same_v<InputT, bfloat8_t>,
+            IsBFloat8Fnuz = std::is_same_v<InputT, bfloat8_fnuz_t>,
 
 #if !ROCWMMA_TESTS_NO_HALF
             IsHFloat16 = std::is_same_v<OutputT, hfloat16_t>,
@@ -151,8 +163,10 @@ namespace rocwmma
         enum struct ComputeType : bool
         {
             IsInt8    = std::is_same_v<ComputeT, int8_t>,
-            IsFloat8  = std::is_same_v<ComputeT, float8_t>,
-            IsBFloat8 = std::is_same_v<ComputeT, bfloat8_t>,
+            IsFloat8  = std::is_same_v<InputT, float8_t>,
+            IsFloat8Fnuz = std::is_same_v<InputT, float8_fnuz_t>,
+            IsBFloat8  = std::is_same_v<InputT, bfloat8_t>,
+            IsBFloat8Fnuz = std::is_same_v<InputT, bfloat8_fnuz_t>,
 
 #if !ROCWMMA_TESTS_NO_HALF
             IsHFloat16 = std::is_same_v<ComputeT, hfloat16_t>,
