@@ -77,6 +77,14 @@ namespace rocwmma
         {
             mGcnArch = hipGcnArch_t::GFX1102;
         }
+        else if(deviceName.find("gfx1200") != std::string::npos)
+        {
+            mGcnArch = hipGcnArch_t::GFX1200;
+        }
+        else if(deviceName.find("gfx1201") != std::string::npos)
+        {
+            mGcnArch = hipGcnArch_t::GFX1201;
+        }
 
         switch(mProps.warpSize)
         {
@@ -91,7 +99,7 @@ namespace rocwmma
         mMaxFreqMhz    = static_cast<int>(static_cast<double>(mProps.clockRate) / 1000.0);
         mCurFreqMhz    = mMaxFreqMhz;
 
-#ifdef ROCWMMA_BENCHMARK_TESTS
+#if ROCWMMA_BENCHMARK_TESTS
         bool smiErrorFlag = false;
         CHECK_RSMI_ERROR(rsmi_init(0), smiErrorFlag);
         if(!smiErrorFlag)
@@ -134,7 +142,7 @@ namespace rocwmma
                 }
             }
         }
-#endif
+#endif // ROCWMMA_BENCHMARK_TESTS
     }
 
     hipDevice_t HipDevice::getDeviceHandle() const
@@ -184,10 +192,10 @@ namespace rocwmma
 
     HipDevice::~HipDevice()
     {
-#ifdef ROCWMMA_BENCHMARK_TESTS
+#if ROCWMMA_BENCHMARK_TESTS
         bool smiErrorFlag = false;
         CHECK_RSMI_ERROR(rsmi_shut_down(), smiErrorFlag);
-#endif
+#endif // ROCWMMA_BENCHMARK_TESTS
     }
 
     // Need to check the host device target support statically before hip modules attempt
