@@ -67,6 +67,24 @@ namespace rocwmma
         };
     };
 
+    template <>
+    struct MfmaPerfTraits<DefaultArch, float8_fnuz_t>
+    {
+        enum : uint32_t
+        {
+            Multiplier = 0
+        };
+    };
+
+    template <>
+    struct MfmaPerfTraits<DefaultArch, bfloat8_fnuz_t>
+    {
+        enum : uint32_t
+        {
+            Multiplier = 0
+        };
+    };
+
     template <>
     struct MfmaPerfTraits<DefaultArch, bfloat16_t>
     {
@@ -140,6 +158,24 @@ namespace rocwmma
         };
     };
 
+    template <>
+    struct MfmaPerfTraits<ArchGfx908, float8_fnuz_t>
+    {
+        enum : uint32_t
+        {
+            Multiplier = 0
+        };
+    };
+
+    template <>
+    struct MfmaPerfTraits<ArchGfx908, bfloat8_fnuz_t>
+    {
+        enum : uint32_t
+        {
+            Multiplier = 0
+        };
+    };
+
     template <>
     struct MfmaPerfTraits<ArchGfx908, bfloat16_t>
     {
@@ -213,6 +249,24 @@ namespace rocwmma
         };
     };
 
+    template <>
+    struct MfmaPerfTraits<ArchGfx90a, float8_fnuz_t>
+    {
+        enum : uint32_t
+        {
+            Multiplier = 0
+        };
+    };
+
+    template <>
+    struct MfmaPerfTraits<ArchGfx90a, bfloat8_fnuz_t>
+    {
+        enum : uint32_t
+        {
+            Multiplier = 0
+        };
+    };
+
     template <>
     struct MfmaPerfTraits<ArchGfx90a, bfloat16_t>
     {
