@@ -38,14 +38,7 @@ namespace rocwmma
     template <uint32_t BlockM,
               uint32_t BlockN,
               typename DataT,
-              typename DataLayout,
-              typename std::enable_if_t<
-                  FragSize_guard<BlockM,
-                                 BlockN,
-                                 DataT,
-                                 DataLayout,
-                                 Constants::AMDGCN_WAVE_SIZE,
-                                 Constants::AMDGCN_CURRENT_ARCH_ID>::enable()>* = nullptr>
+              typename DataLayout>
     __global__ void LoadStoreMatrixSyncA(uint32_t     m,
                                          uint32_t     n,
                                          DataT const* in,
@@ -54,54 +47,34 @@ namespace rocwmma
                                          DataT        param1,
                                          DataT        param2)
     {
-        using Mapping = MappingUtil<BlockM, BlockN, DataT, DataLayout>;
-
-        // Mapping:
-        // Incoming -> Matrix A (ColNT)
-        // BlockM -> BlockM
-        // <Dummy> -> BlockN
-        // BlockN -> BlockK
-        auto frag = fragment<matrix_a, BlockM, 1, BlockN, DataT, DataLayout>();
-
-        // Map, load and store.
-        auto* read  = Mapping::dataCoord(in, ld);
-        auto* write = Mapping::dataCoord(out, ld);
-        load_matrix_sync(frag, read, ld);
-        store_matrix_sync(write, frag, ld);
-    }
-
-    template <uint32_t BlockM,
-              uint32_t BlockN,
-              typename DataT,
-              typename DataLayout,
-              typename std::enable_if_t<
-                  !FragSize_guard<BlockM,
-                                  BlockN,
-                                  DataT,
-                                  DataLayout,
-                                  Constants::AMDGCN_WAVE_SIZE,
-                                  Constants::AMDGCN_CURRENT_ARCH_ID>::enable()>* = nullptr>
-    __global__ void LoadStoreMatrixSyncA(uint32_t     m,
-                                         uint32_t     n,
-                                         DataT const* in,
-                                         DataT*       out,
-                                         uint32_t     ld,
-                                         DataT        param1,
-                                         DataT        param2)
-    {
-    }
-
-    template <uint32_t BlockM,
-              uint32_t BlockN,
-              typename DataT,
-              typename DataLayout,
-              typename std::enable_if_t<
-                  FragSize_guard<BlockM,
+        if constexpr (FragSize_guard<BlockM,
                                  BlockN,
                                  DataT,
                                  DataLayout,
                                  Constants::AMDGCN_WAVE_SIZE,
-                                 Constants::AMDGCN_CURRENT_ARCH_ID>::enable()>* = nullptr>
+                                 Constants::AMDGCN_CURRENT_ARCH_ID>::enable())
+        {
+            using Mapping = MappingUtil<BlockM, BlockN, DataT, DataLayout>;
+
+            // Mapping:
+            // Incoming -> Matrix A (ColNT)
+            // BlockM -> BlockM
+            // <Dummy> -> BlockN
+            // BlockN -> BlockK
+            auto frag = fragment<matrix_a, BlockM, 1, BlockN, DataT, DataLayout>();
+
+            // Map, load and store.
+            auto* read  = Mapping::dataCoord(in, ld);
+            auto* write = Mapping::dataCoord(out, ld);
+            load_matrix_sync(frag, read, ld);
+            store_matrix_sync(write, frag, ld);
+        }
+    }
+
+    template <uint32_t BlockM,
+              uint32_t BlockN,
+              typename DataT,
+              typename DataLayout>
     __global__ void LoadStoreMatrixSyncB(uint32_t     m,
                                          uint32_t     n,
                                          DataT const* in,
@@ -110,89 +83,34 @@ namespace rocwmma
                                          DataT        param1,
                                          DataT        param2)
     {
-        using Mapping = MappingUtil<BlockM, BlockN, DataT, DataLayout>;
-
-        // Mapping:
-        // Incoming -> Matrix B (RowNT)
-        // <Dummy> -> BlockM
-        // BlockN -> BlockN
-        // BlockM -> BlockK
-        auto frag = fragment<matrix_b, 1, BlockN, BlockM, DataT, DataLayout>();
-
-        // Map, load and store.
-        auto* read  = Mapping::dataCoord(in, ld);
-        auto* write = Mapping::dataCoord(out, ld);
-        load_matrix_sync(frag, read, ld);
-        store_matrix_sync(write, frag, ld);
-    }
-
-    template <uint32_t BlockM,
-              uint32_t BlockN,
-              typename DataT,
-              typename DataLayout,
-              typename std::enable_if_t<
-                  !FragSize_guard<BlockM,
-                                  BlockN,
-                                  DataT,
-                                  DataLayout,
-                                  Constants::AMDGCN_WAVE_SIZE,
-                                  Constants::AMDGCN_CURRENT_ARCH_ID>::enable()>* = nullptr>
-    __global__ void LoadStoreMatrixSyncB(uint32_t     m,
-                                         uint32_t     n,
-                                         DataT const* in,
-                                         DataT*       out,
-                                         uint32_t     ld,
-                                         DataT        param1,
-                                         DataT        param2)
-    {
-    }
-
-    template <uint32_t BlockM,
-              uint32_t BlockN,
-              typename DataT,
-              typename DataLayout,
-              typename std::enable_if_t<
-                  FragSize_guard<BlockM,
+        if constexpr (FragSize_guard<BlockM,
                                  BlockN,
                                  DataT,
                                  DataLayout,
                                  Constants::AMDGCN_WAVE_SIZE,
-                                 Constants::AMDGCN_CURRENT_ARCH_ID>::enable()>* = nullptr>
-    __global__ void LoadStoreMatrixSyncAcc(uint32_t     m,
-                                           uint32_t     n,
-                                           DataT const* in,
-                                           DataT*       out,
-                                           uint32_t     ld,
-                                           DataT        param1,
-                                           DataT        param2)
-    {
-        using Mapping = MappingUtil<BlockM, BlockN, DataT, DataLayout>;
+                                 Constants::AMDGCN_CURRENT_ARCH_ID>::enable())
+        {
+            using Mapping = MappingUtil<BlockM, BlockN, DataT, DataLayout>;
 
-        // Mapping:
-        // Incoming -> Matrix C (Row4T)
-        // BlockM -> BlockM
-        // BlockN -> BlockN
-        // <Dummy> -> BlockK
-        auto frag = fragment<accumulator, BlockM, BlockN, 1, DataT, DataLayout>();
+            // Mapping:
+            // Incoming -> Matrix B (RowNT)
+            // <Dummy> -> BlockM
+            // BlockN -> BlockN
+            // BlockM -> BlockK
+            auto frag = fragment<matrix_b, 1, BlockN, BlockM, DataT, DataLayout>();
 
-        // Map, load and store.
-        auto* read  = Mapping::dataCoord(in, ld);
-        auto* write = Mapping::dataCoord(out, ld);
-        load_matrix_sync(frag, read, ld);
-        store_matrix_sync(write, frag, ld);
+            // Map, load and store.
+            auto* read  = Mapping::dataCoord(in, ld);
+            auto* write = Mapping::dataCoord(out, ld);
+            load_matrix_sync(frag, read, ld);
+            store_matrix_sync(write, frag, ld);
+        }
     }
 
     template <uint32_t BlockM,
               uint32_t BlockN,
               typename DataT,
-              typename DataLayout,
-              typename std::enable_if_t<
-                  !FragSize_guard<BlockM,
-                                  BlockN,
-                                  DataT,
-                                  DataLayout,
-                                  Constants::AMDGCN_WAVE_SIZE,
-                                  Constants::AMDGCN_CURRENT_ARCH_ID>::enable()>* = nullptr>
+              typename DataLayout>
     __global__ void LoadStoreMatrixSyncAcc(uint32_t     m,
                                            uint32_t     n,
                                            DataT const* in,
@@ -201,6 +119,28 @@ namespace rocwmma
                                            DataT        param1,
                                            DataT        param2)
     {
+        if constexpr (FragSize_guard<BlockM,
+                                 BlockN,
+                                 DataT,
+                                 DataLayout,
+                                 Constants::AMDGCN_WAVE_SIZE,
+                                 Constants::AMDGCN_CURRENT_ARCH_ID>::enable())
+        {
+            using Mapping = MappingUtil<BlockM, BlockN, DataT, DataLayout>;
+
+            // Mapping:
+            // Incoming -> Matrix C (Row4T)
+            // BlockM -> BlockM
+            // BlockN -> BlockN
+            // <Dummy> -> BlockK
+            auto frag = fragment<accumulator, BlockM, BlockN, 1, DataT, DataLayout>();
+
+            // Map, load and store.
+            auto* read  = Mapping::dataCoord(in, ld);
+            auto* write = Mapping::dataCoord(out, ld);
+            load_matrix_sync(frag, read, ld);
+            store_matrix_sync(write, frag, ld);
+        }
     }
 
 } // namespace rocwmma
